pub struct ChatCompletionRequestAssistantMessage {
pub content: Option<ChatCompletionRequestAssistantMessageContent>,
pub reasoning_content: Option<ReasoningContent>,
pub refusal: Option<String>,
pub name: Option<String>,
pub audio: Option<ChatCompletionRequestAssistantMessageAudio>,
pub tool_calls: Option<Vec<ChatCompletionMessageToolCall>>,
pub function_call: Option<FunctionCall>,
}Fields
content: Option<ChatCompletionRequestAssistantMessageContent>The contents of the assistant message. Required unless tool_calls or function_call is specified.
reasoning_content: Option<ReasoningContent>Reasoning content from a previous assistant turn.
When serialized as a plain string, represents a flat reasoning block (backward-compatible with Jinja chat templates). When serialized as an array of strings, represents interleaved reasoning segments preserving per-position order for KV cache correctness.
refusal: Option<String>The refusal message by the assistant.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.
audio: Option<ChatCompletionRequestAssistantMessageAudio>Data about a previous audio response from the model. Learn more.
tool_calls: Option<Vec<ChatCompletionMessageToolCall>>function_call: Option<FunctionCall>Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.