ChatCompletionStreamOptions

Struct ChatCompletionStreamOptions 

pub struct ChatCompletionStreamOptions {
    pub include_usage: bool,
    pub continuous_usage_stats: bool,
}
Options for streaming response. Only set this when you set stream: true.

Fields

include_usage: bool

If set, an additional chunk will be streamed before the data: [DONE] message. The usage field on this chunk shows the token usage statistics for the entire request, and the choices field will always be an empty array. All other chunks will also include a usage field, but with a null value.

continuous_usage_stats: bool

NVIDIA-specific and industrial common extensions for per chunk usage reporting.