pub struct CreateChatCompletionResponse {
pub id: String,
pub choices: Vec<ChatChoice>,
pub created: u32,
pub model: String,
pub service_tier: Option<ServiceTierResponse>,
pub system_fingerprint: Option<String>,
pub object: String,
pub usage: Option<CompletionUsage>,
pub nvext: Option<Value>,
}Expand description
Represents a chat completion response returned by model, based on the provided input.
Fields
id: StringA unique identifier for the chat completion.
choices: Vec<ChatChoice>A list of chat completion choices. Can be more than one if n is greater than 1.
created: u32The Unix timestamp (in seconds) of when the chat completion was created.
model: StringThe model used for the chat completion.
service_tier: Option<ServiceTierResponse>The service tier used for processing the request. This field is only included if the service_tier parameter is specified in the request.
system_fingerprint: Option<String>This fingerprint represents the backend configuration that the model runs with.
Can be used in conjunction with the seed request parameter to understand when backend changes have been made that might impact determinism.
object: StringThe object type, which is always chat.completion.
usage: Option<CompletionUsage>nvext: Option<Value>NVIDIA extension field for response metadata (worker IDs, etc.)