CreateChatCompletionStreamResponse

Struct CreateChatCompletionStreamResponse 

pub struct CreateChatCompletionStreamResponse {
    pub id: String,
    pub choices: Vec<ChatChoiceStream>,
    pub created: u32,
    pub model: String,
    pub service_tier: Option<ServiceTierResponse>,
    pub system_fingerprint: Option<String>,
    pub object: String,
    pub usage: Option<CompletionUsage>,
    pub nvext: Option<Value>,
}
Represents a streamed chunk of a chat completion response returned by model, based on the provided input.

Fields

id: String

A unique identifier for the chat completion. Each chunk has the same ID.

choices: Vec<ChatChoiceStream>

A list of chat completion choices. Can contain more than one elements if n is greater than 1. Can also be empty for the last chunk if you set stream_options: {"include_usage": true}.

created: u32

The Unix timestamp (in seconds) of when the chat completion was created. Each chunk has the same timestamp.

model: String

The model to generate the completion.

service_tier: Option<ServiceTierResponse>

The service tier used for processing the request. This field is only included if the service_tier parameter is specified in the request.

system_fingerprint: Option<String>

This fingerprint represents the backend configuration that the model runs with. Can be used in conjunction with the seed request parameter to understand when backend changes have been made that might impact determinism.

object: String

The object type, which is always chat.completion.chunk.

usage: Option<CompletionUsage>

An optional field that will only be present when you set stream_options: {"include_usage": true} in your request. When present, it contains a null value except for the last chunk which contains the token usage statistics for the entire request.

nvext: Option<Value>

NVIDIA extension field for response metadata